Module: Xmi::Namespace::Dynamic
- Defined in:
- lib/xmi/namespace/dynamic.rb
Overview
Module for dynamically created namespace classes These are created when loading EA MDG extensions
Class Method Summary collapse
-
.ensure_exists! ⇒ Object
Ensure the Dynamic namespace module exists This is a no-op since the module is already defined.
Class Method Details
.ensure_exists! ⇒ Object
Ensure the Dynamic namespace module exists This is a no-op since the module is already defined
11 12 13 |
# File 'lib/xmi/namespace/dynamic.rb', line 11 def ensure_exists! # Already defined by Ruby when this file is loaded end |